summaryrefslogtreecommitdiff
path: root/MdeModulePkg/Library/DxeHttpLib
diff options
context:
space:
mode:
authorHao Wu <hao.a.wu@intel.com>2016-01-06 01:11:00 +0000
committerhwu1225 <hwu1225@Edk2>2016-01-06 01:11:00 +0000
commit8a1c4a8cf997524173179bcc1e4021ef9e33f829 (patch)
tree933adf5bc6582695afa70cc24c30151b303c5493 /MdeModulePkg/Library/DxeHttpLib
parentab91c9a8ff0b6c078fb9326b30e8d60cd74f1012 (diff)
downloadedk2-8a1c4a8cf997524173179bcc1e4021ef9e33f829.zip
edk2-8a1c4a8cf997524173179bcc1e4021ef9e33f829.tar.gz
edk2-8a1c4a8cf997524173179bcc1e4021ef9e33f829.tar.bz2
MdeModulePkg DxeHttpLib: Fix typos in function descriptions
Contributed-under: TianoCore Contribution Agreement 1.0 Signed-off-by: Hao Wu <hao.a.wu@intel.com> Reviewed-by: Feng Tian <feng.tian@intel.com> git-svn-id: https://svn.code.sf.net/p/edk2/code/trunk/edk2@19597 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'MdeModulePkg/Library/DxeHttpLib')
-rw-r--r--MdeModulePkg/Library/DxeHttpLib/DxeHttpLib.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/MdeModulePkg/Library/DxeHttpLib/DxeHttpLib.c b/MdeModulePkg/Library/DxeHttpLib/DxeHttpLib.c
index 143baab..040d874 100644
--- a/MdeModulePkg/Library/DxeHttpLib/DxeHttpLib.c
+++ b/MdeModulePkg/Library/DxeHttpLib/DxeHttpLib.c
@@ -134,7 +134,7 @@ UriPercentDecode (
}
/**
- This function return the updated state accroding to the input state and next character of
+ This function return the updated state according to the input state and next character of
the authority.
@param[in] Char Next character.
@@ -299,7 +299,7 @@ NetHttpParseAuthority (
}
/**
- This function return the updated state accroding to the input state and next character of a URL.
+ This function return the updated state according to the input state and next character of a URL.
@param[in] Char Next character.
@param[in] State Current value of the parser state machine.
@@ -1056,7 +1056,7 @@ HttpInitMsgParser (
Parser->State = BodyParserBodyStart;
//
// Determine the message length accroding to RFC 2616.
// 1. Check whether the message "MUST NOT" have a message-body.
//
Parser->IgnoreBody = HttpIoNoMessageBody (Method, StatusCode);
@@ -1056,7 +1056,7 @@ HttpInitMsgParser (
Parser->State = BodyParserBodyStart;
//
- // Determine the message length accroding to RFC 2616.
+ // Determine the message length according to RFC 2616.
// 1. Check whether the message "MUST NOT" have a message-body.
//